@@ -1,3 +1,5 @@
+''' Modeling of the mean / average component of wind velocity '''
+
 import abc
 import random
 from math import cos, radians, sin
@@ -6,39 +8,27 @@ import numpy as np
 import pandas as pd
 from scipy.stats import rv_histogram
 
-from MAPLEAF.Interpolation import linInterp
-from MAPLEAF.IO.SimDefinition import defaultConfigValues
+from MAPLEAF.Motion.Interpolation import linInterp
+from MAPLEAF.IO.SimDefinition import defaultConfigValues, getAbsoluteFilePath
 from MAPLEAF.IO.SubDictReader import SubDictReader
 from MAPLEAF.Motion.CythonVector import Vector
 
-__pdoc__ = {
-    '_meanWindModel_Constant':            True,
-    '_meanWindModel_Hellman':             True,
-    '_meanWindModel_InterpolatedProfile': True,
-    '_windRoseDataSampler':               True,
-    '_radioSondeDataSampler':             True,
-}
 
 # Mean Wind Model Abstract Base Class / Interface Definition
 class MeanWindModel(abc.ABC):
-    ''' Defines the interface for Mean Wind Models instantiated by meanWindModelFactory.    '''
+    ''' Defines the interface for Mean Wind Models '''
 
     @abc.abstractmethod
     def getMeanWind(self, AGLAltitude):
-        pass
+        pass 
 
 # Mean Wind Model Factory
-def meanWindModelFactory(simDefinition=None, silent=False):
-    '''
-        Arguments: 
-            simDefinition: A SimDefinition containing the simulation definition file for the present simulation
+def meanWindModelFactory(simDefinition=None, silent=False) -> MeanWindModel:
+    ''' Instantiates a mean wind model '''
 
-        Returns:
-            meanWindModel, created based on the parameters provided in the SimDefinition passed in 
-    '''
     if simDefinition == None:
         constWind = Vector(defaultConfigValues["Environment.ConstantMeanWind.velocity"])
-        return _meanWindModel_Constant(constWind)
+        return Constant(constWind)
 
     envReader = SubDictReader('Environment', simDefinition)
     meanWindModel = None
@@ -49,7 +39,7 @@ def meanWindModelFactory(simDefinition=None, silent=False):
         if not silent:
             print("Constant ground wind: {:1.2f} m/s".format(meanGroundWind))
 
-        meanWindModel = _meanWindModel_Constant(meanGroundWind)
+        meanWindModel = Constant(meanGroundWind)
 
     elif meanWindModelType in [ "SampledGroundWindData", "Hellman" ]:
         def getLocationSampledGroundWindVel():
@@ -64,7 +54,7 @@ def meanWindModelFactory(simDefinition=None, silent=False):
             launchMonth = envReader.getString("SampledGroundWindData.launchMonth")
 
             # Sample wind rose(s)
-            sampler = _windRoseDataSampler(silent=silent)
+            sampler = WindRoseDataSampler(silent=silent)
             meanGroundWind = sampler.sampleWindRoses(locationsSampled, locationWeights, launchMonth)
 
             # Output choices parsed from input file and resulting wind
@@ -87,7 +77,7 @@ def meanWindModelFactory(simDefinition=None, silent=False):
             meanGroundWind = getLocationSampledGroundWindVel()
             if not silent:
                 print("Wind is not a function of altitude")
-            meanWindModel = _meanWindModel_Constant(meanGroundWind)
+            meanWindModel = Constant(meanGroundWind)
 
         elif meanWindModelType == "Hellman":
             groundWindModel = envReader.getString("Hellman.groundWindModel")
@@ -106,11 +96,11 @@ def meanWindModelFactory(simDefinition=None, silent=False):
                 print("Wind vs. altitude governed by Hellman law: v2 = v1*(z2/10)^a where a = {}".format(HellmanAlphaCoeff))
                 print("Hellman law is taken to apply up to an altitude of {} m AGL".format(HellmanAltitudeLimit))
 
-            meanWindModel = _meanWindModel_Hellman(meanGroundWind, HellmanAltitudeLimit, HellmanAlphaCoeff)
+            meanWindModel = Hellman(meanGroundWind, HellmanAltitudeLimit, HellmanAlphaCoeff)
     
     elif meanWindModelType == "CustomWindProfile":
         meanWindProfileFilePath = envReader.getString("CustomWindProfile.filePath")
-        meanWindModel = _meanWindModel_InterpolatedProfile(windFilePath=meanWindProfileFilePath)
+        meanWindModel = InterpolatedProfile(windFilePath=meanWindProfileFilePath)
 
     elif meanWindModelType == "SampledRadioSondeData":
         # Get locations and location weights
@@ -130,18 +120,18 @@ def meanWindModelFactory(simDefinition=None, silent=False):
         radioSondeRandomSeed = envReader.tryGetString("SampledRadioSondeData.randomSeed")
 
         # Select and parse radio sonde profile
-        sampler = _radioSondeDataSampler(silent=silent)
+        sampler = RadioSondeDataSampler(silent=silent)
         altitudes, windVectors = sampler.getRadioSondeWindProfile(locations, weights, locationASLAltitudes, launchMonth, radioSondeRandomSeed)
         
-        meanWindModel = _meanWindModel_InterpolatedProfile(windAltitudes=altitudes, winds=windVectors)
+        meanWindModel = InterpolatedProfile(windAltitudes=altitudes, winds=windVectors)
 
     else:
         raise ValueError("Unknown MeanWindModel: {}. Please see SimDefinitionTemplate.txt for available options.".format(meanWindModelType))
 
     return meanWindModel
 
-# Actual Mean Wind Model classes - these are instantiated by meanWindModelFactory
-class _meanWindModel_Constant(MeanWindModel):
+#### Actual Mean Wind Model classes - these are instantiated by meanWindModelFactory ####
+class Constant(MeanWindModel):
     ''' Defines a constant wind speed at all altitudes  '''
     
     def __init__(self, wind):
@@ -150,7 +140,7 @@ class _meanWindModel_Constant(MeanWindModel):
     def getMeanWind(self, AGLAltitude):
         return self.wind
 
-class _meanWindModel_Hellman(MeanWindModel):
+class Hellman(MeanWindModel):
     '''
         Uses the Hellman law to scale a ground velocity using a power law as the atmospheric boundary layer is exited.
         Low-altitude only. https://en.wikipedia.org/wiki/Wind_gradient -> Engineering Section.
@@ -173,7 +163,7 @@ class _meanWindModel_Hellman(MeanWindModel):
         # Assume initial winds come from a height of 10m
         return self.groundMeanWind * (HellmanAltitude/10)**self.hellmanAlphaCoeff
 
-class _meanWindModel_InterpolatedProfile(MeanWindModel):
+class InterpolatedProfile(MeanWindModel):
     def __init__(self, windAltitudes=[], winds=[], windFilePath=None):
         '''
             Arguments:
@@ -207,7 +197,7 @@ class _meanWindModel_InterpolatedProfile(MeanWindModel):
         return Vector(*linInterp(self.windAltitudes, self.winds, AGLAltitude))
 
 # Wind Data readers/samplers
-class _windRoseDataSampler():
+class WindRoseDataSampler():
     ''' 
         Parses wind rose data files from Iowa State University's Environmental Mesonet.
     '''
@@ -271,10 +261,11 @@ class _windRoseDataSampler():
         return windRose
 
     def _getAveragedWindRose(self, Months=["May"], MonthWeights=[1.0], locations=["MedecineHat"], locationWeights=[1.0]):
-        windRose = self._readWindRose("test/WindData/WindroseAprMedecineHat.txt")*0.0 # Initialize as zero
+        windRose = self._readWindRose(getAbsoluteFilePath("MAPLEAF/Examples/Wind/WindroseAprMedecineHat.txt"))*0.0 # Initialize as zero
         for i in range(len(Months)):
             for a in range(len(locations)):
-                windRoseFilePath = "test/WindData/Windrose{}{}.txt".format(Months[i], locations[a])
+                windRoseFilePath = "MAPLEAF/Examples/Wind/Windrose{}{}.txt".format(Months[i], locations[a])
+                windRoseFilePath = getAbsoluteFilePath(windRoseFilePath)
                 windRose += self._readWindRose(windRoseFilePath) * MonthWeights[i] * locationWeights[a]
 
         return windRose.copy()
@@ -338,9 +329,9 @@ class _windRoseDataSampler():
         #TODO: Need to de-rotate these headings by 5 degrees?
         return rv_histogram((likelyhoodByHeading, headings))
 
-class _radioSondeDataSampler():
+class RadioSondeDataSampler():
     ''' 
-        Parses data from radio sonde data files from IGRA-2 after they've been post-processed by test/WindData/filterRadioSondeData.py
+        Parses data from radio sonde data files from IGRA-2 after they've been post-processed by MAPLEAF/Examples/Wind/filterRadioSondeData.py
         IGRA-2 format info: https://www1.ncdc.noaa.gov/pub/data/igra/data/igra2-data-format.txt
     '''
 
@@ -369,7 +360,9 @@ class _radioSondeDataSampler():
 
         locationASLAltitude = locationASLAltitudes[locations.index(selectedLocation)]
         # Load radiosonde data for that location
-        radioSondeFilePath = "test/WindData/RadioSonde{}_filtered.txt".format(selectedLocation)
+        radioSondeFilePath = "MAPLEAF/Examples/Wind/RadioSonde{}_filtered.txt".format(selectedLocation)
+        # Convert to absolute file path
+        radioSondeFilePath = getAbsoluteFilePath(radioSondeFilePath)
         
         # Read datasets from fille
         if launchMonth != "Yearly":
@@ -470,7 +463,7 @@ class _radioSondeDataSampler():
             Both returned lists are sorted from lowest to highest altitude
 
             Further info about radio sonde input data at: https://www1.ncdc.noaa.gov/pub/data/igra/data/igra2-data-format.txt
-            Input data expects that radio sonde data has already been reduced to just the altitude, wind heading and wind speed columsn using test/WindData/filterRadioSondeData.py
+            Input data expects that radio sonde data has already been reduced to just the altitude, wind heading and wind speed columsn using MAPLEAF/Examples/Wind/filterRadioSondeData.py
         '''
         result = []
         for line in data:
@@ -505,62 +498,3 @@ def _convertWindHeadingToXYPlaneWindDirection(heading, AngleBetweenYAxisandNorth
     headingVector = Vector(x, y, 0)
     windDirectionVector = -1 * headingVector # Wind is in opposite direction of heading
     return windDirectionVector
-
-#If this file is run by itself
-# if __name__ == '__main__':
-    # from SimDefinition import SimDefinition
-    # fW = SimDefinition("test/simDefinitions/Wind.txt")
-    # fW.setValue("Environment.MeanWindModel", "SampledGroundWindData")
-
-    # a = meanWindModelFactory(fW)
-
-    # import matplotlib.pyplot as plt
-    # plt.figure(figsize=(3.5,3))
-    # plt.rcParams["font.family"] = "Times New Roman"
-    # plt.rcParams["font.size"] = "10"
-
-
-
-
-    # print("Plotting using scipy rv_histogram")
-    # rvHist = a._createHeadingCDF_scipy(wR, windSpeed=5)
-
-    # values = []
-    # for i in range(10000):
-    #     # Sample the rv_histogram using ppf function (Quantile)
-    #     values.append(rvHist.ppf(random.random()))
-
-    # plt.hist(values, bins=36, cumulative=True, density=True, label="Sampled CDF")
-
-    # X = np.linspace(0, 360, 100)
-    # plt.plot(X, rvHist.pdf(X)*100, label="PDF")
-    # plt.plot(X, rvHist.cdf(X), label="CDF")
-
-    # plt.legend()
-
-    # plt.show()
-
-
-
-
-    #### Plot radiosonde wind profile ####
-    # from math import atan2, degrees
-    # windHeadings = [ degrees(atan2(-x, -y)) for x,y,z in a.winds ]
-    # for i in range(len(windHeadings)):
-    #     if windHeadings[i] < 0:
-    #         windHeadings[i] += 360
-    # windSpeeds = [ np.linalg.norm(x) for x in a.winds ]
-    # altitudes = [ x / 1000 for x in a.windAltitudes ]
-
-
-    # plt.plot(altitudes, windHeadings, label="Wind heading (degrees)")
-    # plt.plot(altitudes, windSpeeds, label="Wind speed (m/s)")
-    # plt.legend()
-    # plt.ylim([0,350])
-    # plt.xlim([0, 35])
-    # plt.xlabel("Altitude (km, AGL)")
-    # plt.tight_layout()
-    # plt.savefig("C:/Users/rando/Documents/flightSimPaper/Figures/Images/SampleRadioSondeProfile_Edmonton20120304_12.eps", bbox_inches="tight", pad_inches=0)
-
-
-    # plt.show()
