@@ -1,8 +1,9 @@
 # Created by: Henry Stoldt
 # April 2020
 
-# File contains plotting functions
-# Used by the function "runSimulation" in  Main.py
+'''
+Functions to create plots and animations of simulations results.
+'''
 
 import re
 from bisect import bisect_right
@@ -16,7 +17,7 @@ import mpl_toolkits.mplot3d.axes3d as p3
 import numpy as np
 import pandas as pd
 
-from MAPLEAF.Interpolation import interpolateRigidBodyStates, linInterpWeights
+from MAPLEAF.Motion.Interpolation import interpolateRigidBodyStates, linInterpWeights
 from MAPLEAF.IO.RocketFlight import RocketFlight
 from MAPLEAF.Motion.CythonQuaternion import Quaternion
 from MAPLEAF.Motion.CythonVector import Vector
@@ -309,7 +310,7 @@ def plotFlightPaths_FullEarth(flightPaths, showPlot=True):
         plotFlightPaths_NoEarth(flightPaths)
 
 ### Flight Animation ###
-def _keepNTimeSteps(flights, nFramesToKeep=900):
+def _keepNTimeSteps(flights, nFramesToKeep=600):
     '''
         Pass in list of RocketFlight objects and the number of frames/timesteps you'd like to keep
         Will return a matching list of Rocket Flight objects with linearly-interpolated, evenly spaced (in time) timesteps
@@ -320,48 +321,48 @@ def _keepNTimeSteps(flights, nFramesToKeep=900):
         flights = [ flights ]
 
     maxLength = len(flights[0].times)
-    if maxLength > nFramesToKeep:
-        # Find the max flight time of any stage
-        maxTime = 0
-        for flight in flights:
-            if flight.times[-1] > maxTime:
-                maxTime = flight.times[-1]
+    
+    # Find the max flight time of any stage
+    maxTime = 0
+    for flight in flights:
+        if flight.times[-1] > maxTime:
+            maxTime = flight.times[-1]
 
-        newTimes = np.linspace(0, maxTime, num=nFramesToKeep)
+    newTimes = np.linspace(0, maxTime, num=nFramesToKeep)
 
-        for flight in flights:
-            # Interpolate flights to the times in newTimes
-            interpStates = []
+    for flight in flights:
+        # Interpolate flights to the times in newTimes
+        interpStates = []
 
-            interpCanardDefls = None
+        interpCanardDefls = None
+        if flight.actuatorDefls != None:
+            nCanards = len(flight.actuatorDefls)
+            interpCanardDefls = [ [] for i in range(nCanards) ]
+
+        for time in newTimes:
+            # SmallYIndex, SmallYWeight, largeYIndex, largeYWeight (for linear interpolation)
+            smY, smYW, lgY, lgYW = linInterpWeights(flight.times, time)
+
+            # Interpolate rigid body state
+            if type(flight.rigidBodyStates[smY]) == type(flight.rigidBodyStates[lgY]):
+                interpolatedState = interpolateRigidBodyStates(flight.rigidBodyStates[smY], flight.rigidBodyStates[lgY], smYW)
+            else:
+                # Handles the switch from 6DoF to 3DoF, where two adjacent states will be of different types
+                interpolatedState = flight.rigidBodyStates[lgY] if lgYW > smYW else flight.rigidBodyStates[smY]
+
+            interpStates.append(interpolatedState)
+
+            # Interpolate canard deflections
             if flight.actuatorDefls != None:
-                nCanards = len(flight.actuatorDefls)
-                interpCanardDefls = [ [] for i in range(nCanards) ]
-
-            for time in newTimes:
-                # SmallYIndex, SmallYWeight, largeYIndex, largeYWeight (for linear interpolation)
-                smY, smYW, lgY, lgYW = linInterpWeights(flight.times, time)
-
-                # Interpolate rigid body state
-                if type(flight.rigidBodyStates[smY]) == type(flight.rigidBodyStates[lgY]):
-                    interpolatedState = interpolateRigidBodyStates(flight.rigidBodyStates[smY], flight.rigidBodyStates[lgY], smYW)
-                else:
-                    # Handles the switch from 6DoF to 3DoF, where two adjacent states will be of different types
-                    interpolatedState = flight.rigidBodyStates[lgY] if lgYW > smYW else flight.rigidBodyStates[smY]
-
-                interpStates.append(interpolatedState)
-
-                # Interpolate canard deflections
-                if flight.actuatorDefls != None:
-                    for i in range(nCanards):
-                        # Interpolate the deflection of each canard
-                        interpolatedDeflection = flight.actuatorDefls[i][smY]*smYW + flight.actuatorDefls[i][lgY]*lgYW
-                        interpCanardDefls[i].append(interpolatedDeflection)
-            
-            flight.times = newTimes
-            flight.rigidBodyStates = interpStates
-            if flight.actuatorDefls != None:
-                flight.actuatorDefls = interpCanardDefls
+                for i in range(nCanards):
+                    # Interpolate the deflection of each canard
+                    interpolatedDeflection = flight.actuatorDefls[i][smY]*smYW + flight.actuatorDefls[i][lgY]*lgYW
+                    interpCanardDefls[i].append(interpolatedDeflection)
+        
+        flight.times = newTimes
+        flight.rigidBodyStates = interpStates
+        if flight.actuatorDefls != None:
+            flight.actuatorDefls = interpCanardDefls
 
     if unpackResult:
         return flights[0]
@@ -378,7 +379,11 @@ def _get3DPlotSize(Positions, sizeMultiple=1.1):
     yRange = max(Positions[1]) - min(Positions[1])
     zRange = max(Positions[2]) - min(Positions[2])
 
-    axisDimensions = max([xRange, yRange, zRange]) * sizeMultiple
+    if max(xRange, yRange, zRange) == 0:
+        # For cases where the object does not move
+        axisDimensions = 1.0
+    else:
+        axisDimensions = max([xRange, yRange, zRange]) * sizeMultiple
     
     return axisDimensions, centerOfPlot
 
@@ -391,7 +396,7 @@ def _findEventTimeStepNumber(flight, time):
     else:
         return bisect_right(flight.times, time) # Binary search for time value in 
 
-def _createReferenceVectors(nCanards, maxAbsCoord, rocketLengthFactor=0.3, finLengthFactor=0.1):
+def _createReferenceVectors(nCanards, maxAbsCoord, rocketLengthFactor=0.25, finLengthFactor=0.05):
     '''
         Creates a longitudinal vector and an array of nCanards perpendicular vectors. 
         These represent the rocket in the local frame and are rotated according to it's rigid body state at each time step.
@@ -419,9 +424,9 @@ def _createAnimationFigure(axisDimensions, centerOfPlot):
     ax.set_xlim3d([centerOfPlot[0] - halfDim, centerOfPlot[0] + halfDim])
     ax.set_ylim3d([centerOfPlot[1] - halfDim, centerOfPlot[1] + halfDim])
     ax.set_zlim3d([centerOfPlot[2] - halfDim, centerOfPlot[2] + halfDim])
-    ax.set_xlabel('X')
-    ax.set_ylabel('Y')
-    ax.set_zlabel('Z')
+    ax.set_xlabel('X (m)')
+    ax.set_ylabel('Y (m)')
+    ax.set_zlabel('Z (m)')
 
     return fig, ax
 
@@ -526,9 +531,9 @@ def _getRocketPoints(timeStepNumber, flight, refAxis, perpVectors):
         tip = rocketBase - refAxis*0.2
 
         if flight.mainChuteDeployTime == None or timeStepNumber < flight.mainChuteTimeStep:
-            chuteSize = 0.5
+            chuteSize = 0.35
         else:
-            chuteSize = 1.5
+            chuteSize = 1.0
 
         perpTips = [ rocketBase + x*chuteSize + axisVector for x in perpVectors ]
         canardTips = perpTips
@@ -614,7 +619,7 @@ def flightAnimation(flights, showPlot=True, saveAnimFileName=None):
     '''
     #### Set up data for animation ####
     # Filter out extra frames - seems like there's a limit to the number of frames that will work well with matplotlib, otherwise the end of the animation is weirdly sped up
-    flights = _keepNTimeSteps(flights, nFramesToKeep=600)
+    flights = _keepNTimeSteps(flights, nFramesToKeep=900)
 
     # Transform position info into arrays of x, y, z coordinates
     for flight in flights:
