@@ -2,8 +2,7 @@
 Input/Output functionality:
 
 * Reading/Writing Simulation Definition Files
-* Plotting results
-* Logging results
+* Plotting/Logging results
 
 .. image:: https://upload.wikimedia.org/wikipedia/commons/thumb/f/f8/Laptop-hard-drive-exposed.jpg/1280px-Laptop-hard-drive-exposed.jpg
 '''
\ No newline at end of file
