@@ -6,7 +6,7 @@ from math import asin, cos, degrees, radians, sqrt
 
 import numpy as np
 
-import MAPLEAF.Interpolation as Interpolation
+import MAPLEAF.Motion.Interpolation as Interpolation
 import MAPLEAF.Rocket.AeroFunctions as AeroFunctions
 from MAPLEAF.ENV.Environment import EnvironmentalConditions
 from MAPLEAF.GNC.ActuatedSystem import ActuatedSystem
@@ -45,6 +45,7 @@ def getBusemannCoefficients(Mach, beta, gamma=1.4):
     return K1, K2, K3
 
 class FinSet(FixedMass, ActuatedSystem):
+    ''' Class represents a set of n identical fins, all at the same longitudinal location, arranged axisymmetrically. Fin orientations can be controlled by a `MAPLEAF.GNC.ControlSystems.ControlSystem` '''
 
     #### Initialization Functions ####
     def __init__(self, componentDictReader, rocket, stage):
@@ -430,6 +431,7 @@ class FinSet(FixedMass, ActuatedSystem):
             plt.plot (Xvals, Yvals, color = 'k')
 
 class Fin(FixedMass):
+    ''' Represents a single fin in a FinSet '''
 
     def __init__(self, componentDictReader, parentFinSet, spanwiseDirection, rocket, stage):
 
